==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/FastStochasticOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { FastStochasticOscillatorIndicatorDescription } from "./FastStochasticOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let FastStochasticOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class FastStochasticOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (FastStochasticOscillatorIndicatorDescriptionMetadata.a == null) {
                FastStochasticOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FastStochasticOscillatorIndicatorDescriptionMetadata.c(FastStochasticOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(FastStochasticOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(FastStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            FastStochasticOscillatorIndicatorDescriptionMetadata.b(a);
            a.ad("FastStochasticOscillatorIndicator", () => new FastStochasticOscillatorIndicatorDescription());
            a.ac("FastStochasticOscillatorIndicator", FastStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    FastStochasticOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(FastStochasticOscillatorIndicatorDescriptionMetadata, 'FastStochasticOscillatorIndicatorDescriptionMetadata');
    FastStochasticOscillatorIndicatorDescriptionMetadata.a = null;
    return FastStochasticOscillatorIndicatorDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/FastStochasticOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { FastStochasticOscillatorIndicatorDescription } from "./FastStochasticOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let FastStochasticOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class FastStochasticOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (FastStochasticOscillatorIndicatorDescriptionMetadata.a == null) {
                FastStochasticOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FastStochasticOscillatorIndicatorDescriptionMetadata.c(FastStochasticOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(FastStochasticOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(FastStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("Period", "Number:int");
        }
        static d(a) {
            FastStochasticOscillatorIndicatorDescriptionMetadata.b(a);
            a.ae("FastStochasticOscillatorIndicator", () => new FastStochasticOscillatorIndicatorDescription());
            a.ad("FastStochasticOscillatorIndicator", FastStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    FastStochasticOscillatorIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(FastStochasticOscillatorIndicatorDescriptionMetadata, 'FastStochasticOscillatorIndicatorDescriptionMetadata');
    FastStochasticOscillatorIndicatorDescriptionMetadata.a = null;
    return FastStochasticOscillatorIndicatorDescriptionMetadata;
})();
